Client

Struct Client 

pub struct Client { /* private fields */ }
Manages access to the Something Awful forums.

Implementations

Source

impl Client

pub fn new() -> Result<Client, Error>

Constructs an unauthenticated client. The user must either login or load credentials before using other API functions.

pub async fn login(&self, username: &str, password: &str) -> Result<(), Error>

Attempts to login. Returns ReqwestError on a communication error or LoginError if the login request failed.

pub async fn fetch_profile<'a>( &self, user: User<'a>, ) -> Result<Option<Profile>, Error>

Returns the profile of a user, or None if that user cannot be found.

pub async fn fetch_posts( &self, thread_id: &str, index: ThreadPage, ) -> Result<Vec<Post>, Error>

Returns all posts on a given page of a thread.

pub async fn fetch_bookmarked_threads(&self) -> Result<Vec<Thread>, Error>

Returns metadata about all bookmarked threads.

pub fn save_credentials<W: Write>(&self, writer: &mut W) -> Result<(), Error>

Saves credentials to JSON. The user must be logged in for the credentials to be useful.

pub fn load_credentials<R: BufRead>(&self, reader: R) -> Result<(), Error>

Loads credentials from JSON. The JSON must have been written with save_credentials.