pub struct Thread {
pub id: String,
pub title: String,
pub author_username: String,
pub replies: i64,
pub views: i64,
pub last_post_date: String,
pub last_post_username: String,
pub unread: i64,
}Expand description
Represents a single thread within a list of threads.
Fields
id: Stringtitle: Stringreplies: i64views: i64last_post_date: Stringlast_post_username: Stringunread: i64Zero if there are no unread posts in this thread. Otherwise, the number of unread posts.
Implementations